/* -*- Mode: idl; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Oracle Corporation code.
 *
 * The Initial Developer of the Original Code is
 *  Oracle Corporation
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Vladimir Vukicevic <vladimir.vukicevic@oracle.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "calIItemBase.idl"

interface calIDuration;

//
// calIEvent
//
// An interface for an event (analogous to a VEVENT)
//

[scriptable, uuid(5ab15c1c-e295-4d8e-a9a9-ba5bc848b59a)]
interface calIEvent : calIItemBase
{
  // these attributes are marked readonly, as the calIDates are owned
  // by the event; however, the actual calIDate objects are not read
  // only and are intended to be manipulated to adjust dates.
  
  /**
   * The (inclusive) start of the event.
   */
  attribute calIDateTime startDate;

  /**
   * The (non-inclusive) end of the event.
   * Note that for all-day events, non-inclusive means that this will be set
   * to the day after the last day of the event.
   * If startDate.isDate is set, endDate.isDate must also be set.
   */
  attribute calIDateTime endDate;

  /**
   * The duration of the event.
   * equal to endDate - startDate
   */
  readonly attribute calIDuration duration;

};
